@@ -21,7 +21,6 @@
 #include "cdrizzleutil.h"
 #include "drizzletest.h"
 
-
 FILE *logptr = NULL;
 static integer_t image_size[2];
 static PyArrayObject *test_data;
@@ -34,13 +33,8 @@ static PyArrayObject *test_context;
 static char log_file[] = "";
 
 void
-set_test_arrays(PyArrayObject *dat,
-                PyArrayObject *wei,
-                PyArrayObject *map,
-                PyArrayObject *odat,
-                PyArrayObject *ocnt,
-                PyArrayObject *ocon) {
-
+set_test_arrays(PyArrayObject *dat, PyArrayObject *wei, PyArrayObject *map,
+                PyArrayObject *odat, PyArrayObject *ocnt, PyArrayObject *ocon) {
     test_data = dat;
     test_weights = wei;
     test_pixmap = map;
@@ -59,13 +53,13 @@ set_pixmap(struct driz_param_t *p, int xmin, int xmax, int ymin, int ymax) {
 
     ypix = ymin;
     for (j = ymin; j < ymax; j++) {
-       xpix = xmin;
-       for (i = xmin; i < xmax; i++) {
+        xpix = xmin;
+        for (i = xmin; i < xmax; i++) {
             get_pixmap(p->pixmap, i, j)[0] = xpix;
             get_pixmap(p->pixmap, i, j)[1] = ypix;
             xpix += 1.0;
-       }
-       ypix += 1.0;
+        }
+        ypix += 1.0;
     }
 
     return;
@@ -79,19 +73,18 @@ init_pixmap(struct driz_param_t *p) {
 
 void
 stretch_pixmap(struct driz_param_t *p, double stretch) {
-
     int i, j;
     double xpix, ypix;
 
     ypix = 0.0;
     for (j = 0; j < image_size[1]; j++) {
-       xpix = 0.0;
-       for (i= 0; i < image_size[0]; i++) {
+        xpix = 0.0;
+        for (i = 0; i < image_size[0]; i++) {
             get_pixmap(p->pixmap, i, j)[0] = xpix;
             get_pixmap(p->pixmap, i, j)[1] = stretch * ypix;
             xpix += 1.0;
-       }
-       ypix += 1.0;
+        }
+        ypix += 1.0;
     }
 
     return;
@@ -102,10 +95,10 @@ nan_pixmap(struct driz_param_t *p) {
     int i, j;
 
     for (j = 0; j < image_size[1]; j++) {
-       for (i= 0; i < image_size[0]; i++) {
+        for (i = 0; i < image_size[0]; i++) {
             get_pixmap(p->pixmap, i, j)[0] = NPY_NAN;
             get_pixmap(p->pixmap, i, j)[1] = NPY_NAN;
-       }
+        }
     }
 
     return;
@@ -115,25 +108,24 @@ void
 nan_pixel(struct driz_param_t *p, int xpix, int ypix) {
     int idim;
     for (idim = 0; idim < 2; ++idim) {
-         get_pixmap(p->pixmap, xpix, ypix)[idim] = NPY_NAN;
+        get_pixmap(p->pixmap, xpix, ypix)[idim] = NPY_NAN;
     }
 }
 
 void
 offset_pixmap(struct driz_param_t *p, double x_offset, double y_offset) {
-
     int i, j;
     double xpix, ypix;
 
     ypix = y_offset;
     for (j = 0; j < image_size[1]; j++) {
-       xpix = x_offset;
-       for (i = 0; i < image_size[0]; i++) {
+        xpix = x_offset;
+        for (i = 0; i < image_size[0]; i++) {
             get_pixmap(p->pixmap, i, j)[0] = xpix;
             get_pixmap(p->pixmap, i, j)[1] = ypix;
             xpix += 1.0;
-       }
-       ypix += 1.0;
+        }
+        ypix += 1.0;
     }
 
     return;
@@ -141,7 +133,7 @@ offset_pixmap(struct driz_param_t *p, double x_offset, double y_offset) {
 
 void
 fill_image(PyArrayObject *image, double value) {
-    npy_intp   *ndim = PyArray_DIMS(image);
+    npy_intp *ndim = PyArray_DIMS(image);
     int ypix, xpix;
 
     for (ypix = 0; ypix < ndim[0]; ++ypix) {
@@ -154,7 +146,7 @@ fill_image(PyArrayObject *image, double value) {
 }
 
 void
-fill_image_block(PyArrayObject* image, double value, int lo, int hi) {
+fill_image_block(PyArrayObject *image, double value, int lo, int hi) {
     int ypix, xpix;
 
     for (ypix = lo; ypix < hi; ++ypix) {
@@ -167,7 +159,7 @@ fill_image_block(PyArrayObject* image, double value, int lo, int hi) {
 }
 void
 unset_context(PyArrayObject *context) {
-    npy_intp   *ndim = PyArray_DIMS(context);
+    npy_intp *ndim = PyArray_DIMS(context);
     int ypix, xpix;
 
     for (ypix = 0; ypix < ndim[0]; ++ypix) {
@@ -180,7 +172,7 @@ unset_context(PyArrayObject *context) {
 }
 
 void
-print_image(char *title, PyArrayObject* image, int lo, int hi) {
+print_image(char *title, PyArrayObject *image, int lo, int hi) {
     int j, i;
 
     if (logptr) {
@@ -225,17 +217,18 @@ print_context(char *title, struct driz_param_t *p, int lo, int hi) {
 
 void
 print_pixmap(char *title, struct driz_param_t *p, int lo, int hi) {
-    int     i, j, k;
+    int i, j, k;
     char *axis[2] = {"x", "y"};
 
     if (logptr) {
-        for (k = 0; k < 2; k ++) {
+        for (k = 0; k < 2; k++) {
             fprintf(logptr, "\n%s %s axis\n", title, axis[k]);
 
-            for (j = 0; j < image_size[1]; j++ ) {
+            for (j = 0; j < image_size[1]; j++) {
                 for (i = 0; i < image_size[0]; i++) {
                     if (i >= lo && i < hi && j >= lo && j < hi) {
-                        fprintf(logptr, "%10.2f", get_pixmap(p->pixmap, i, j)[k]);
+                        fprintf(logptr, "%10.2f",
+                                get_pixmap(p->pixmap, i, j)[k]);
                     }
                 }
 
@@ -254,7 +247,7 @@ setup_parameters() {
     /* Initialize the parameter struct with vanilla defaults */
 
     struct driz_param_t *p;
-    p = (struct driz_param_t *) malloc(sizeof(struct driz_param_t));
+    p = (struct driz_param_t *)malloc(sizeof(struct driz_param_t));
 
     driz_param_init(p);
 
@@ -280,7 +273,7 @@ setup_parameters() {
     p->nmiss = 0;
     p->nskip = 0;
 
-    error = (struct driz_error_t *) malloc(sizeof(struct driz_error_t));
+    error = (struct driz_error_t *)malloc(sizeof(struct driz_error_t));
     driz_error_init(error);
     p->error = error;
     init_pixmap(p);
@@ -302,7 +295,6 @@ setup_parameters() {
 
 void
 teardown_parameters(struct driz_param_t *p) {
-
     if (logptr) {
         fclose(logptr);
         logptr = NULL;
@@ -312,24 +304,17 @@ teardown_parameters(struct driz_param_t *p) {
     free(p);
 }
 
-FCT_BGN_FN(utest_cdrizzle)
-{
-    FCT_FIXTURE_SUITE_BGN("unit tests for drizzle")
-    {
-        FCT_SETUP_BGN()
-        {
-        }
+FCT_BGN_FN(utest_cdrizzle) {
+    FCT_FIXTURE_SUITE_BGN("unit tests for drizzle") {
+        FCT_SETUP_BGN() {}
         FCT_SETUP_END();
 
-        FCT_TEARDOWN_BGN()
-        {
-        }
+        FCT_TEARDOWN_BGN() {}
         FCT_TEARDOWN_END();
 
-        FCT_TEST_BGN(utest_shrink_bbox)
-        {
+        FCT_TEST_BGN(utest_shrink_bbox) {
             int xmin, xmax, ymin, ymax;
-            struct driz_param_t *p;     /* parameter structure */
+            struct driz_param_t *p; /* parameter structure */
 
             p = setup_parameters();
             nan_pixmap(p);
@@ -359,8 +344,7 @@ FCT_BGN_FN(utest_cdrizzle)
         }
         FCT_TEST_END();
 
-        FCT_TEST_BGN(utest_map_lookup_01)
-        {
+        FCT_TEST_BGN(utest_map_lookup_01) {
             struct driz_param_t *p;
             p = setup_parameters();
             stretch_pixmap(p, 1000.0);
@@ -375,8 +359,7 @@ FCT_BGN_FN(utest_cdrizzle)
         }
         FCT_TEST_END();
 
-        FCT_TEST_BGN(utest_map_lookup_02)
-        {
+        FCT_TEST_BGN(utest_map_lookup_02) {
             struct driz_param_t *p;
             p = setup_parameters();
             stretch_pixmap(p, 1000.0);
@@ -391,8 +374,7 @@ FCT_BGN_FN(utest_cdrizzle)
         }
         FCT_TEST_END();
 
-        FCT_TEST_BGN(utest_map_lookup_03)
-        {
+        FCT_TEST_BGN(utest_map_lookup_03) {
             struct driz_param_t *p;
             p = setup_parameters();
             stretch_pixmap(p, 1000.0);
@@ -406,8 +388,7 @@ FCT_BGN_FN(utest_cdrizzle)
         }
         FCT_TEST_END();
 
-        FCT_TEST_BGN(utest_map_lookup_04)
-        {
+        FCT_TEST_BGN(utest_map_lookup_04) {
             struct driz_param_t *p;
             p = setup_parameters();
             stretch_pixmap(p, 1000.0);
@@ -421,8 +402,7 @@ FCT_BGN_FN(utest_cdrizzle)
         }
         FCT_TEST_END();
 
-        FCT_TEST_BGN(utest_map_point_01)
-        {
+        FCT_TEST_BGN(utest_map_point_01) {
             double ix, iy, ox, oy;
             struct driz_param_t *p;
 
@@ -441,8 +421,7 @@ FCT_BGN_FN(utest_cdrizzle)
         }
         FCT_TEST_END();
 
-        FCT_TEST_BGN(utest_map_point_02)
-        {
+        FCT_TEST_BGN(utest_map_point_02) {
             double ix, iy, ox, oy;
             struct driz_param_t *p;
 
@@ -461,8 +440,7 @@ FCT_BGN_FN(utest_cdrizzle)
         }
         FCT_TEST_END();
 
-        FCT_TEST_BGN(utest_map_point_03)
-        {
+        FCT_TEST_BGN(utest_map_point_03) {
             double ix, iy, ox, oy;
             int status;
             struct driz_param_t *p;
@@ -490,8 +468,7 @@ FCT_BGN_FN(utest_cdrizzle)
         }
         FCT_TEST_END();
 
-        FCT_TEST_BGN(utest_map_point_04)
-        {
+        FCT_TEST_BGN(utest_map_point_04) {
             double ix, iy, ox, oy;
             int status;
             struct driz_param_t *p;
@@ -520,20 +497,19 @@ FCT_BGN_FN(utest_cdrizzle)
         }
         FCT_TEST_END();
 
-        FCT_TEST_BGN(utest_check_line_overlap_01)
-        {
+        FCT_TEST_BGN(utest_check_line_overlap_01) {
             struct scanner s;
             int ymin, ymax, shift, status;
 
             /* Test for complete overlap */
 
-            const integer_t j = 0;      /* which image line to check ? */
-            integer_t xbounds[2];       /* start of in-bounds */
-            struct driz_param_t *p;     /* parameter structure */
+            const integer_t j = 0;  /* which image line to check ? */
+            integer_t xbounds[2];   /* start of in-bounds */
+            struct driz_param_t *p; /* parameter structure */
 
             p = setup_parameters();
             shift = 0;
-            offset_pixmap(p, (double) shift, 0.0);
+            offset_pixmap(p, (double)shift, 0.0);
 
             init_image_scanner(p, &s, &ymin, &ymax);
             status = get_scanline_limits(&s, j, &xbounds[0], &xbounds[1]);
@@ -545,25 +521,23 @@ FCT_BGN_FN(utest_cdrizzle)
             fct_chk_eq_int(xbounds[1], MAX(0, MIN(image_size[0] - 1 - shift,
                                                   image_size[0] - 1)));
 
-
             teardown_parameters(p);
         }
         FCT_TEST_END();
 
-        FCT_TEST_BGN(utest_check_line_overlap_02)
-        {
+        FCT_TEST_BGN(utest_check_line_overlap_02) {
             struct scanner s;
             int ymin, ymax, shift, status;
 
             /* Test for half overlap */
 
-            const integer_t j = 0;      /* which image line to check ? */
-            integer_t xbounds[2];       /* start of in-bounds */
-            struct driz_param_t *p;     /* parameter structure */
+            const integer_t j = 0;  /* which image line to check ? */
+            integer_t xbounds[2];   /* start of in-bounds */
+            struct driz_param_t *p; /* parameter structure */
 
             p = setup_parameters();
             shift = 70;
-            offset_pixmap(p, (double) shift, 0.0);
+            offset_pixmap(p, (double)shift, 0.0);
 
             init_image_scanner(p, &s, &ymin, &ymax);
             status = get_scanline_limits(&s, j, &xbounds[0], &xbounds[1]);
@@ -579,20 +553,19 @@ FCT_BGN_FN(utest_cdrizzle)
         }
         FCT_TEST_END();
 
-        FCT_TEST_BGN(utest_check_line_overlap_03)
-        {
+        FCT_TEST_BGN(utest_check_line_overlap_03) {
             struct scanner s;
             int ymin, ymax, shift, status;
 
             /* Test for negative half overlap */
 
-            const integer_t j = 0;      /* which image line to check ? */
-            integer_t xbounds[2];       /* start of in-bounds */
-            struct driz_param_t *p;     /* parameter structure */
+            const integer_t j = 0;  /* which image line to check ? */
+            integer_t xbounds[2];   /* start of in-bounds */
+            struct driz_param_t *p; /* parameter structure */
 
             p = setup_parameters();
             shift = -70;
-            offset_pixmap(p, (double) shift, 0.0);
+            offset_pixmap(p, (double)shift, 0.0);
 
             init_image_scanner(p, &s, &ymin, &ymax);
             status = get_scanline_limits(&s, j, &xbounds[0], &xbounds[1]);
@@ -608,19 +581,17 @@ FCT_BGN_FN(utest_cdrizzle)
         }
         FCT_TEST_END();
 
-        FCT_TEST_BGN(utest_check_image_overlap_02)
-        {
+        FCT_TEST_BGN(utest_check_image_overlap_02) {
             struct scanner s;
             int ymin, ymax, shift;
 
             /* Test for half overlap */
 
-            integer_t ybounds[2];       /* start of in-bounds */
-            struct driz_param_t *p;     /* parameter structure */
+            struct driz_param_t *p; /* parameter structure */
 
             p = setup_parameters();
             shift = 70;
-            offset_pixmap(p, 0.0, (double) shift);
+            offset_pixmap(p, 0.0, (double)shift);
 
             init_image_scanner(p, &s, &ymin, &ymax);
 
@@ -632,19 +603,17 @@ FCT_BGN_FN(utest_cdrizzle)
         }
         FCT_TEST_END();
 
-        FCT_TEST_BGN(utest_check_image_overlap_03)
-        {
+        FCT_TEST_BGN(utest_check_image_overlap_03) {
             struct scanner s;
             int ymin, ymax, shift;
 
             /* Test for negative half overlap */
 
-            integer_t ybounds[2];       /* start of in-bounds */
-            struct driz_param_t *p;     /* parameter structure */
+            struct driz_param_t *p; /* parameter structure */
 
             p = setup_parameters();
             shift = -70;
-            offset_pixmap(p, 0.0, (double) shift);
+            offset_pixmap(p, 0.0, (double)shift);
 
             init_image_scanner(p, &s, &ymin, &ymax);
 
@@ -656,8 +625,7 @@ FCT_BGN_FN(utest_cdrizzle)
         }
         FCT_TEST_END();
 
-        FCT_TEST_BGN(utest_compute_area_01)
-        {
+        FCT_TEST_BGN(utest_compute_area_01) {
             /* Test compute area with aligned square entirely inside */
             double area;
             double is, js, x[4], y[4];
@@ -676,12 +644,10 @@ FCT_BGN_FN(utest_cdrizzle)
 
             area = compute_area(is, js, x, y);
             fct_chk_eq_dbl(area, 0.25);
-
         }
         FCT_TEST_END();
 
-        FCT_TEST_BGN(utest_compute_area_02)
-        {
+        FCT_TEST_BGN(utest_compute_area_02) {
             /* Test compute area with diagonal square entirely inside */
             double area;
             double is, js, x[4], y[4];
@@ -700,12 +666,10 @@ FCT_BGN_FN(utest_cdrizzle)
 
             area = compute_area(is, js, x, y);
             fct_chk_eq_dbl(area, 0.125);
-
         }
         FCT_TEST_END();
 
-        FCT_TEST_BGN(utest_compute_area_03)
-        {
+        FCT_TEST_BGN(utest_compute_area_03) {
             /* Test compute area with aligned square with overlap */
             double area;
             double is, js, x[4], y[4];
@@ -724,12 +688,10 @@ FCT_BGN_FN(utest_cdrizzle)
 
             area = compute_area(is, js, x, y);
             fct_chk_eq_dbl(area, 0.25);
-
         }
         FCT_TEST_END();
 
-        FCT_TEST_BGN(utest_compute_area_04)
-        {
+        FCT_TEST_BGN(utest_compute_area_04) {
             /* Test compute area with diagonal square with overlap */
             double area;
             double is, js, x[4], y[4];
@@ -748,37 +710,41 @@ FCT_BGN_FN(utest_cdrizzle)
 
             area = compute_area(is, js, x, y);
             fct_chk_eq_dbl(area, 0.0625);
-
         }
         FCT_TEST_END();
 
-        FCT_TEST_BGN(utest_compute_area_05)
-        {
+        FCT_TEST_BGN(utest_compute_area_05) {
             /* Test compute area with marching diagonal square */
             int i, j;
             double is, js, x[4], y[4], area;
-            double area_ok[7][7] =
-                {{0.125000, 0.218750, 0.250000, 0.218750, 0.125000, 0.031250, 0.000000},
-                 {0.218750, 0.375000, 0.437500, 0.375000, 0.218750, 0.062500, 0.000000},
-                 {0.250000, 0.437500, 0.500000, 0.437500, 0.250000, 0.062500, 0.000000},
-                 {0.218750, 0.375000, 0.437500, 0.375000, 0.218750, 0.062500, 0.000000},
-                 {0.125000, 0.218750, 0.250000, 0.218750, 0.125000, 0.031250, 0.000000},
-                 {0.031250, 0.062500, 0.062500, 0.062500, 0.031250, 0.000000, 0.000000},
-                 {0.000000, 0.000000, 0.000000, 0.000000, 0.000000, 0.000000, 0.000000}};
+            double area_ok[7][7] = {{0.125000, 0.218750, 0.250000, 0.218750,
+                                     0.125000, 0.031250, 0.000000},
+                                    {0.218750, 0.375000, 0.437500, 0.375000,
+                                     0.218750, 0.062500, 0.000000},
+                                    {0.250000, 0.437500, 0.500000, 0.437500,
+                                     0.250000, 0.062500, 0.000000},
+                                    {0.218750, 0.375000, 0.437500, 0.375000,
+                                     0.218750, 0.062500, 0.000000},
+                                    {0.125000, 0.218750, 0.250000, 0.218750,
+                                     0.125000, 0.031250, 0.000000},
+                                    {0.031250, 0.062500, 0.062500, 0.062500,
+                                     0.031250, 0.000000, 0.000000},
+                                    {0.000000, 0.000000, 0.000000, 0.000000,
+                                     0.000000, 0.000000, 0.000000}};
 
             is = 1.0;
             js = 1.0;
 
-            for (i = 0; i <= 6; ++ i) {
-                for (j = 0; j <= 6; ++ j) {
-                    x[0] = 0.25 * (double) i;
-                    y[0] = 0.25 * (double) j + 0.5;
-                    x[1] = 0.25 * (double) i + 0.5;
-                    y[1] = 0.25 * (double) j;
-                    x[2] = 0.25 * (double) i + 1.0;
-                    y[2] = 0.25 * (double) j + 0.5;
-                    x[3] = 0.25 * (double) i + 0.5;
-                    y[3] = 0.25 * (double) j + 1.0;
+            for (i = 0; i <= 6; ++i) {
+                for (j = 0; j <= 6; ++j) {
+                    x[0] = 0.25 * (double)i;
+                    y[0] = 0.25 * (double)j + 0.5;
+                    x[1] = 0.25 * (double)i + 0.5;
+                    y[1] = 0.25 * (double)j;
+                    x[2] = 0.25 * (double)i + 1.0;
+                    y[2] = 0.25 * (double)j + 0.5;
+                    x[3] = 0.25 * (double)i + 0.5;
+                    y[3] = 0.25 * (double)j + 1.0;
 
                     area = compute_area(is, js, x, y);
 
@@ -789,13 +755,12 @@ FCT_BGN_FN(utest_cdrizzle)
         }
         FCT_TEST_END();
 
-       FCT_TEST_BGN(utest_do_kernel_square_01)
-        {
+        FCT_TEST_BGN(utest_do_kernel_square_01) {
             /* Simplest case */
 
-            integer_t x1;               /* start of in-bounds */
-            integer_t j, x2;            /* end of in-bounds */
-            struct driz_param_t *p;     /* parameter structure */
+            integer_t x1;           /* start of in-bounds */
+            integer_t j, x2;        /* end of in-bounds */
+            struct driz_param_t *p; /* parameter structure */
             int n, status;
 
             n = 100;
@@ -810,18 +775,19 @@ FCT_BGN_FN(utest_cdrizzle)
             x2 = n;
 
             fct_chk_eq_int(status, 0);
-            fct_chk_eq_dbl(get_pixel(p->output_data, x1, j), get_pixel(p->data, x1, j));
-            fct_chk_eq_dbl(get_pixel(p->output_data, x2-1, j), get_pixel(p->data, x2-1, j));
+            fct_chk_eq_dbl(get_pixel(p->output_data, x1, j),
+                           get_pixel(p->data, x1, j));
+            fct_chk_eq_dbl(get_pixel(p->output_data, x2 - 1, j),
+                           get_pixel(p->data, x2 - 1, j));
 
             teardown_parameters(p);
         }
         FCT_TEST_END();
 
-         FCT_TEST_BGN(utest_do_kernel_square_02)
-        {
+        FCT_TEST_BGN(utest_do_kernel_square_02) {
             /* Offset image */
 
-            struct driz_param_t *p;     /* parameter structure */
+            struct driz_param_t *p; /* parameter structure */
             integer_t j;
             int k, n, status;
             double offset;
@@ -836,19 +802,19 @@ FCT_BGN_FN(utest_cdrizzle)
             status = do_kernel_square(p);
 
             fct_chk_eq_int(status, 0);
-            for (k = 1; k < n-2; k++) {
-                fct_chk_eq_dbl(get_pixel(p->output_data, (k+1), j), get_pixel(p->data, k, j));
+            for (k = 1; k < n - 2; k++) {
+                fct_chk_eq_dbl(get_pixel(p->output_data, (k + 1), j),
+                               get_pixel(p->data, k, j));
             }
 
             teardown_parameters(p);
         }
         FCT_TEST_END();
 
-        FCT_TEST_BGN(utest_do_kernel_square_03)
-        {
+        FCT_TEST_BGN(utest_do_kernel_square_03) {
             /* Single pixel set */
 
-            struct driz_param_t *p;     /* parameter structure */
+            struct driz_param_t *p; /* parameter structure */
             integer_t j;
             int k, n;
             double offset, value;
@@ -866,17 +832,17 @@ FCT_BGN_FN(utest_cdrizzle)
             k = 3;
             do_kernel_square(p);
 
-            fct_chk_eq_dbl(get_pixel(p->output_data, (k+2), k), get_pixel(p->data, k, k));
+            fct_chk_eq_dbl(get_pixel(p->output_data, (k + 2), k),
+                           get_pixel(p->data, k, k));
 
             teardown_parameters(p);
         }
         FCT_TEST_END();
 
-        FCT_TEST_BGN(utest_do_kernel_square_04)
-        {
+        FCT_TEST_BGN(utest_do_kernel_square_04) {
             /* Single pixel, fractional pixel offset */
 
-            struct driz_param_t *p;     /* parameter structure */
+            struct driz_param_t *p; /* parameter structure */
             integer_t i, j, k;
             double offset, value;
 
@@ -892,7 +858,8 @@ FCT_BGN_FN(utest_cdrizzle)
 
             for (i = 2; i <= 3; ++i) {
                 for (j = 2; j <= 3; ++j) {
-                    fct_chk_eq_dbl(get_pixel(p->output_data, (i+k), (j+k)), value/4.0);
+                    fct_chk_eq_dbl(get_pixel(p->output_data, (i + k), (j + k)),
+                                   value / 4.0);
                 }
             }
 
@@ -900,12 +867,11 @@ FCT_BGN_FN(utest_cdrizzle)
         }
         FCT_TEST_END();
 
-        FCT_TEST_BGN(utest_do_kernel_square_05)
-        {
+        FCT_TEST_BGN(utest_do_kernel_square_05) {
             /* Diagonal line, fractional pixel offset */
 
-            struct driz_param_t *p;     /* parameter structure */
-            integer_t i,j;
+            struct driz_param_t *p; /* parameter structure */
+            integer_t i, j;
             int n;
             double offset, value;
 
@@ -915,28 +881,29 @@ FCT_BGN_FN(utest_cdrizzle)
             p = setup_parameters();
             offset_pixmap(p, offset, offset);
 
-            for (j = 1; j < n-1; ++j) {
+            for (j = 1; j < n - 1; ++j) {
                 set_pixel(p->data, j, j, value);
             }
 
             do_kernel_square(p);
 
             for (i = 4; i < n - 2; ++i) {
-                fct_chk_eq_dbl(get_pixel(p->output_data, i, i), value/2.0);
-                fct_chk_eq_dbl(get_pixel(p->output_data, i-1, i), value/4.0);
-                fct_chk_eq_dbl(get_pixel(p->output_data, i, i-1), value/4.0);
+                fct_chk_eq_dbl(get_pixel(p->output_data, i, i), value / 2.0);
+                fct_chk_eq_dbl(get_pixel(p->output_data, i - 1, i),
+                               value / 4.0);
+                fct_chk_eq_dbl(get_pixel(p->output_data, i, i - 1),
+                               value / 4.0);
             }
 
             teardown_parameters(p);
         }
         FCT_TEST_END();
 
-        FCT_TEST_BGN(utest_do_kernel_square_06)
-        {
+        FCT_TEST_BGN(utest_do_kernel_square_06) {
             /* Block of pixels, whole number offset */
 
-            struct driz_param_t *p;     /* parameter structure */
-            integer_t i,j;
+            struct driz_param_t *p; /* parameter structure */
+            integer_t i, j;
             int k;
             double offset, value;
 
@@ -956,7 +923,8 @@ FCT_BGN_FN(utest_cdrizzle)
 
             for (i = 0; i < k; ++i) {
                 for (j = 0; j < k; ++j) {
-                    fct_chk_eq_dbl(get_pixel(p->output_data, (i+2), (j+2)), value);
+                    fct_chk_eq_dbl(get_pixel(p->output_data, (i + 2), (j + 2)),
+                                   value);
                 }
             }
 
@@ -964,11 +932,10 @@ FCT_BGN_FN(utest_cdrizzle)
         }
         FCT_TEST_END();
 
-        FCT_TEST_BGN(utest_do_kernel_square_07)
-        {
+        FCT_TEST_BGN(utest_do_kernel_square_07) {
             /* Block of pixels, fractional offset */
 
-            struct driz_param_t *p;     /* parameter structure */
+            struct driz_param_t *p; /* parameter structure */
             integer_t i, j;
             int k;
             double offset, value;
@@ -979,8 +946,8 @@ FCT_BGN_FN(utest_cdrizzle)
             p = setup_parameters();
             offset_pixmap(p, offset, offset);
 
-            for (i = 1; i < k+1; ++i) {
-                for (j = 1; j < k+1; ++j) {
+            for (i = 1; i < k + 1; ++i) {
+                for (j = 1; j < k + 1; ++j) {
                     set_pixel(p->data, i, j, value);
                 }
             }
@@ -1001,11 +968,10 @@ FCT_BGN_FN(utest_cdrizzle)
         }
         FCT_TEST_END();
 
-        FCT_TEST_BGN(utest_dobox_01)
-        {
+        FCT_TEST_BGN(utest_dobox_01) {
             /* Single pixel set, whole number offset */
 
-            struct driz_param_t *p;     /* parameter structure */
+            struct driz_param_t *p; /* parameter structure */
             int k;
             double offset, value;
 
@@ -1020,16 +986,16 @@ FCT_BGN_FN(utest_cdrizzle)
             set_pixel(p->data, k, k, value);
             dobox(p);
 
-            fct_chk_eq_dbl(get_pixel(p->output_data, (k+2), (k+2)), get_pixel(p->data, k, k));
+            fct_chk_eq_dbl(get_pixel(p->output_data, (k + 2), (k + 2)),
+                           get_pixel(p->data, k, k));
             fct_chk_eq_int(p->nskip, 2);
         }
         FCT_TEST_END();
 
-        FCT_TEST_BGN(utest_dobox_02)
-        {
+        FCT_TEST_BGN(utest_dobox_02) {
             /* Single pixel, fractional pixel offset */
 
-            struct driz_param_t *p;     /* parameter structure */
+            struct driz_param_t *p; /* parameter structure */
             int i, j, k;
             double offset, value;
 
@@ -1046,17 +1012,17 @@ FCT_BGN_FN(utest_cdrizzle)
 
             for (i = 2; i <= 3; ++i) {
                 for (j = 2; j <= 3; ++j) {
-                    fct_chk_eq_dbl(get_pixel(p->output_data, (i+k), (j+k)), value/4.0);
+                    fct_chk_eq_dbl(get_pixel(p->output_data, (i + k), (j + k)),
+                                   value / 4.0);
                 }
             }
         }
         FCT_TEST_END();
 
-        FCT_TEST_BGN(utest_dobox_03)
-        {
+        FCT_TEST_BGN(utest_dobox_03) {
             /* Turbo mode kernel, diagonal line of pixels set */
 
-            struct driz_param_t *p;     /* parameter structure */
+            struct driz_param_t *p; /* parameter structure */
             int i, j, n;
             double offset, value;
 
@@ -1075,20 +1041,21 @@ FCT_BGN_FN(utest_cdrizzle)
             dobox(p);
 
             for (i = 4; i < n; ++i) {
-                fct_chk_eq_dbl(get_pixel(p->output_data, i, i), value/2.0);
-                fct_chk_eq_dbl(get_pixel(p->output_data, i-1, i), value/4.0);
-                fct_chk_eq_dbl(get_pixel(p->output_data, i, i-1), value/4.0);
+                fct_chk_eq_dbl(get_pixel(p->output_data, i, i), value / 2.0);
+                fct_chk_eq_dbl(get_pixel(p->output_data, i - 1, i),
+                               value / 4.0);
+                fct_chk_eq_dbl(get_pixel(p->output_data, i, i - 1),
+                               value / 4.0);
             }
 
             teardown_parameters(p);
         }
         FCT_TEST_END();
 
-        FCT_TEST_BGN(utest_dobox_04)
-        {
+        FCT_TEST_BGN(utest_dobox_04) {
             /* Check that context map is set for the affected pixels */
 
-            struct driz_param_t *p;     /* parameter structure */
+            struct driz_param_t *p; /* parameter structure */
             int i, j, n;
             double offset, value;
             integer_t bv;
@@ -1101,7 +1068,7 @@ FCT_BGN_FN(utest_cdrizzle)
             offset_pixmap(p, offset, offset);
             // DBG p->kernel = kernel_turbo;
 
-            for (j = 1; j < n-1; ++j) {
+            for (j = 1; j < n - 1; ++j) {
                 set_pixel(p->data, j, j, value);
             }
 
@@ -1115,11 +1082,10 @@ FCT_BGN_FN(utest_cdrizzle)
         }
         FCT_TEST_END();
 
-        FCT_TEST_BGN(utest_doblot_01)
-        {
+        FCT_TEST_BGN(utest_doblot_01) {
             /* Single pixel set blinear interpolation */
 
-            struct driz_param_t *p;     /* parameter structure */
+            struct driz_param_t *p; /* parameter structure */
             int k;
             double offset, value;
 
@@ -1135,15 +1101,15 @@ FCT_BGN_FN(utest_cdrizzle)
             set_pixel(p->data, k, k, value);
             doblot(p);
 
-           fct_chk_eq_dbl(get_pixel(p->output_data, (k+2), (k+2)), get_pixel(p->data, k, k));
+            fct_chk_eq_dbl(get_pixel(p->output_data, (k + 2), (k + 2)),
+                           get_pixel(p->data, k, k));
         }
         FCT_TEST_END();
 
-        FCT_TEST_BGN(utest_doblot_02)
-        {
+        FCT_TEST_BGN(utest_doblot_02) {
             /* Single pixel set quintic interpolation*/
 
-            struct driz_param_t *p;     /* parameter structure */
+            struct driz_param_t *p; /* parameter structure */
             int k;
             double offset, value;
 
@@ -1159,11 +1125,11 @@ FCT_BGN_FN(utest_cdrizzle)
             set_pixel(p->data, k, k, value);
             doblot(p);
 
-            fct_chk_eq_dbl(get_pixel(p->output_data, (k+2), (k+2)), get_pixel(p->data, k, k));
+            fct_chk_eq_dbl(get_pixel(p->output_data, (k + 2), (k + 2)),
+                           get_pixel(p->data, k, k));
         }
         FCT_TEST_END();
-
-   }
+    }
     FCT_FIXTURE_SUITE_END();
 }
 FCT_END_FN();
